pub struct HardhatCommand<C: HardhatCommandContext> { /* private fields */ }Implementations
Sourceimpl<C> HardhatCommand<C>where
C: HardhatCommandContext,
impl<C> HardhatCommand<C>where
C: HardhatCommandContext,
pub fn new() -> Result<Self>
Sourcepub fn new_with<P>(hardhat_root: P) -> Result<Self>
pub fn new_with<P>(hardhat_root: P) -> Result<Self>
Create new hardhat network instance with hardhat project root path.
Sourcepub fn is_started(&self) -> bool
pub fn is_started(&self) -> bool
Returns if network started.
Sourcepub async fn start(&mut self) -> Result<bool>
pub async fn start(&mut self) -> Result<bool>
Start hardhat network child process.
If already started, returns false.
Sourcepub async fn stop(&mut self) -> Result<()>
pub async fn stop(&mut self) -> Result<()>
Stop hardhat network.
If hardhat network already stopped, returns HardhatError::HardhatNetworkStopped
Sourcepub async fn status(&mut self) -> Result<ExitStatus>
pub async fn status(&mut self) -> Result<ExitStatus>
Wait until child process stopped and returns status code.